@@ -24,9 +24,39 @@
 #include <gtk/gtk.h>
 
 #include "terminal-screen.h"
+#include "terminal-options.h"
 
 G_BEGIN_DECLS
 
+/* Terminal conf files */
+
+#define TERMINAL_CONFIG_VERSION             (1) /* Bump this for any changes */
+#define TERMINAL_CONFIG_COMPAT_VERSION      (1) /* Bump this for incompatible changes */
+
+#define TERMINAL_CONFIG_GROUP               "GNOME Terminal Configuration"
+#define TERMINAL_CONFIG_PROP_FACTORY        "FactoryEnabled"
+#define TERMINAL_CONFIG_PROP_VERSION        "Version"
+#define TERMINAL_CONFIG_PROP_COMPAT_VERSION "CompatVersion"
+#define TERMINAL_CONFIG_PROP_WINDOWS        "Windows"
+
+#define TERMINAL_CONFIG_WINDOW_PROP_ACTIVE_TAB       "ActiveTerminal"
+#define TERMINAL_CONFIG_WINDOW_PROP_FULLSCREEN       "Fullscreen"
+#define TERMINAL_CONFIG_WINDOW_PROP_GEOMETRY         "Geometry"
+#define TERMINAL_CONFIG_WINDOW_PROP_MAXIMIZED        "Maximized"
+#define TERMINAL_CONFIG_WINDOW_PROP_MENUBAR_VISIBLE  "MenubarVisible"
+#define TERMINAL_CONFIG_WINDOW_PROP_ROLE             "Role"
+#define TERMINAL_CONFIG_WINDOW_PROP_TABS             "Terminals"
+
+#define TERMINAL_CONFIG_TERMINAL_PROP_HEIGHT             "Height"
+#define TERMINAL_CONFIG_TERMINAL_PROP_COMMAND            "Command"
+#define TERMINAL_CONFIG_TERMINAL_PROP_PROFILE_ID         "ProfileID"
+#define TERMINAL_CONFIG_TERMINAL_PROP_TITLE              "Title"
+#define TERMINAL_CONFIG_TERMINAL_PROP_WIDTH              "Width"
+#define TERMINAL_CONFIG_TERMINAL_PROP_WORKING_DIRECTORY  "WorkingDirectory"
+#define TERMINAL_CONFIG_TERMINAL_PROP_ZOOM               "Zoom"
+
+/* Configuration */
+
 #define CONF_PREFIX           "/apps/gnome-terminal"
 #define CONF_GLOBAL_PREFIX    CONF_PREFIX "/global"
 #define CONF_PROFILES_PREFIX  CONF_PREFIX "/profiles"
@@ -39,6 +69,8 @@ G_BEGIN_DECLS
 #define TERMINAL_APP_ENABLE_MNEMONICS       "enable-mnemonics"
 #define TERMINAL_APP_SYSTEM_FONT            "system-font"
 
+#define EPSILON (1.0e-6)
+
 /* TerminalApp */
 
 #define TERMINAL_TYPE_APP              (terminal_app_get_type ())
@@ -59,6 +91,11 @@ void terminal_app_shutdown (void);
 
 TerminalApp* terminal_app_get (void);
 
+gboolean terminal_app_handle_options (TerminalApp *app,
+                                      TerminalOptions *options,
+                                      gboolean allow_resume,
+                                      GError **error);
+
 void terminal_app_edit_profile (TerminalApp     *app,
                                 TerminalProfile *profile,
                                 GtkWindow       *transient_parent);
@@ -76,6 +113,7 @@ TerminalScreen *terminal_app_new_terminal (TerminalApp     *app,
                                            char           **override_command,
                                            const char      *title,
                                            const char      *working_dir,
+                                           char           **child_env,
                                            double           zoom);
 
 TerminalWindow *terminal_app_get_current_window (TerminalApp *app);
@@ -109,6 +147,13 @@ GHashTable *terminal_app_get_encodings (TerminalApp *app);
 
 GSList* terminal_app_get_active_encodings (TerminalApp *app);
 
+void terminal_app_save_config (TerminalApp *app,
+                               GKeyFile *key_file);
+
+gboolean terminal_app_save_config_file (TerminalApp *app,
+                                        const char *file_name,
+                                        GError **error);
+
 G_END_DECLS
 
 #endif /* !TERMINAL_APP_H */
